@@ -3,7 +3,8 @@
 # Write data in tabular text format
 # Philip R Brenan at gmail dot com, Appa Apps Ltd, 2016
 #-------------------------------------------------------------------------------
-
+# xxx - add an error qr()
+# xxx - a way of making it quiet
 package Data::Table::Text;
 require v5.16.0;
 use warnings FATAL => qw(all);
@@ -14,7 +15,7 @@ use File::Glob qw(:bsd_glob);
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.444';
+our $VERSION = '2017.505';
 
 &saveToS3('DataTableText') if 0;                                                # Save code
 
@@ -125,12 +126,16 @@ sub containingFolder($)
  }
 
 sub xxx(@)                                                                      # Execute a command
- {my @cmd = @_;                                                                 # Command to execute
+ {my @cmd = @_;                                                                 # Command to execute in phrases, although last phrase ccan be an error checking regular expression to apply to confess to any errors in the output
   $_ or confess "Missing command component\n" for @cmd;                         # Check that there are no undefined command components
-  my $c = join ' ', @_;                                                         # Command to execute
+  my $error = $cmd[-1];
+  my $check = ref($error) =~ /RegExp/i;
+  pop @cmd if $check;
+  my $c = join ' ', @cmd;                                                       # Command to execute
   say STDERR timeStamp, " ", $c;
   my $r = qx($c 2>&1);
-  say STDERR $r;
+  print STDERR $r;
+  confess $r if $r and $check and $r =~ m/$error/;                              # Error check if an error checking regular expression has been supplied
   $r
  }
 
@@ -834,7 +839,7 @@ modified under the same terms as Perl itself.
 =cut
 
 __DATA__
-use Test::More tests => 57;
+use Test::More tests => 60;
 if (1)                                                                          # File paths
  {ok filePath   (qw(/aaa bbb ccc ddd.eee)) eq "/aaa/bbb/ccc/ddd.eee";
   ok filePathDir(qw(/aaa bbb ccc ddd))     eq "/aaa/bbb/ccc/ddd/";
@@ -1026,3 +1031,11 @@ END
   ok javaPackage($f) eq "com.xyz";
   unlink $f;
  }
+
+ok xxx("echo aaa")       =~ /aaa/;
+ok xxx("a=aaa;echo \$a") =~ /aaa/;
+
+if (1)
+ {eval {xxx "echo aaa", qr(aaa)};
+  ok $@ =~ /aaa/;
+ }
